==> e107-0.7.20.tbz: www/e107/e107_plugins/log/languages/admin/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Steve Dunstan 2001-2002
|     http://e107.org
|     jalist@e107.org
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/log/languages/admin/English.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
	
define("ADSTAT_ON", "On");
define("ADSTAT_OFF", "Off");
define("ADSTAT_L1", "This plugin will log all visits to your site, and build detailed statistic screens based on the information gathered.");
define("ADSTAT_L2", "The statistics logger has been successfully installed. To activate, please go to the config screen and click Activate.<br /><b>You must set the permissions of the e107_plugins/log/logs folder to 777 (chmod 777)</b>");
define("ADSTAT_L3", "Statistic Logging");
define("ADSTAT_L4", "Activate statistic logging");
define("ADSTAT_L5", "Statistic types");
define("ADSTAT_L6", "Browsers");
define("ADSTAT_L7", "Operating Systems");
define("ADSTAT_L8", "Screen resolutions / depths");
define("ADSTAT_L9", "Countries/domains visited from");
define("ADSTAT_L10", "Referrers");
define("ADSTAT_L11", "Search queries");
define("ADSTAT_L12", "Reset stats");
define("ADSTAT_L13", "this will erase stats - careful!");
define("ADSTAT_L14", "Page counts");
define("ADSTAT_L15", "Update Statistic Settings");
define("ADSTAT_L16", "Site Statistic Settings");
define("ADSTAT_L17", "Statistic settings updated");
define("ADSTAT_L18", "Allow access to main statistics page to ...");
define("ADSTAT_L19", "Recent visitors");
define("ADSTAT_L20", "Count admin visits");
define("ADSTAT_L21", "Maximum records to display on stats page");
define("ADSTAT_L22", "Run update routine");
define("ADSTAT_L23", "logs from a previous version of e107 have been detected, update them here");
define("ADSTAT_L24", "Go to update script");
define("ADSTAT_L25", "Selected stats reset");
define("ADSTAT_L26", "Remove page entries");
define("ADSTAT_L27", "If your stats have incorrect pages, you can remove them here");
define("ADSTAT_L28", "Open page");
define("ADSTAT_L29", "Page Name");
define("ADSTAT_L30", "Check to remove");
define("ADSTAT_L31", "Remove selected pages");
define("ADSTAT_L32", "Page Tidy");
define("ADSTAT_L33", "Configure Statistics Logging");
define("ADSTAT_L34", "Site Stats");

define('ADSTAT_L38', "You must set the e107_plugins/log/logs folder to be writable");	// Constant compatible with 0.8


?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/log/languages/admin/English.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system
|
|     Copyright (C) 2001-2002 Steve Dunstan (jalist@e107.org)
|     Copyright (C) 2008-2010 e107 Inc (e107.org)
|
|
|     Released under the terms and conditions of the
|     GNU General Public License (http://gnu.org).
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/log/languages/admin/English.php $
|     $Revision: 12053 $
|     $Id: English.php 12053 2011-01-21 21:59:56Z nlstart $
|     $Author: nlstart $
+----------------------------------------------------------------------------+
*/
	
define("ADSTAT_ON", "On");
define("ADSTAT_OFF", "Off");
define("ADSTAT_L1", "This plugin will log all visits to your site, and build detailed statistic screens based on the information gathered.");
define("ADSTAT_L2", "The statistics logger has been successfully installed. To activate, please go to the config screen and click Activate.<br /><b>You must set the permissions of the e107_plugins/log/logs folder to 777 (chmod 777)</b>");
define("ADSTAT_L3", "Statistic Logging");
define("ADSTAT_L4", "Activate statistic logging");
define("ADSTAT_L5", "Statistic types");
define("ADSTAT_L6", "Browsers");
define("ADSTAT_L7", "Operating Systems");
define("ADSTAT_L8", "Screen resolutions / depths");
define("ADSTAT_L9", "Countries/domains visited from");
define("ADSTAT_L10", "Referrers");
define("ADSTAT_L11", "Search queries");
define("ADSTAT_L12", "Reset stats");
define("ADSTAT_L13", "this will erase stats - careful!");
define("ADSTAT_L14", "Page counts");
define("ADSTAT_L15", "Update Statistic Settings");
define("ADSTAT_L16", "Site Statistic Settings");
define("ADSTAT_L17", "Statistic settings updated");
define("ADSTAT_L18", "Allow access to main statistics page to ...");
define("ADSTAT_L19", "Recent visitors");
define("ADSTAT_L20", "Count admin visits");
define("ADSTAT_L21", "Maximum records to display on stats page");
define("ADSTAT_L22", "Run update routine");
define("ADSTAT_L23", "logs from a previous version of e107 have been detected, update them here");
define("ADSTAT_L24", "Go to update script");
define("ADSTAT_L25", "Selected stats reset");
define("ADSTAT_L26", "Remove page entries");
define("ADSTAT_L27", "If your stats have incorrect pages, you can remove them here");
define("ADSTAT_L28", "Open page");
define("ADSTAT_L29", "Page Name");
define("ADSTAT_L30", "Check to remove");
define("ADSTAT_L31", "Remove selected pages");
define("ADSTAT_L32", "Page Tidy");
define("ADSTAT_L33", "Configure Statistics Logging");
define("ADSTAT_L34", "Site Stats");
define("ADSTAT_L35", "View compact browser info in stats");

define('ADSTAT_L38', "You must set the e107_plugins/log/logs folder to be writable");	// Constant compatible with 0.8
?>
